==> voreen-src-4.0.1-win.zip: voreen-src-4.0.1-win/modules/core/coremoduleqt.cpp <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2012 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#include "coremoduleqt.h"

#include "qt/processor/coreprocessorwidgetfactory.h"
#include "voreen/qt/widgets/property/corepropertywidgetfactory.h"

namespace voreen {

const std::string CoreModuleQt::loggerCat_("voreen.qt.CoreModuleQt");

CoreModuleQt::CoreModuleQt(const std::string& modulePath)
    : VoreenModuleQt(modulePath)
{
    setName("Core (Qt)");

    addShaderPath(getModulePath("glsl/qt"));

    registerProcessorWidgetFactory(new CoreProcessorWidgetFactory());

    registerPropertyWidgetFactory(new CorePropertyWidgetFactory());
}

} // namespace

==> voreen-src-4.4-win.zip: voreen-src-4.4-win/modules/core/coremoduleqt.cpp <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#include "coremoduleqt.h"

#include "qt/processor/coreprocessorwidgetfactory.h"
#include "voreen/qt/widgets/property/corepropertywidgetfactory.h"

namespace voreen {

const std::string CoreModuleQt::loggerCat_("voreen.qt.CoreModuleQt");

CoreModuleQt::CoreModuleQt(const std::string& modulePath)
    : VoreenModuleQt(modulePath)
{
    setID("Core (Qt)");
    setGuiName("Core (Qt)");

    addShaderPath(getModulePath("glsl/qt"));

    registerProcessorWidgetFactory(new CoreProcessorWidgetFactory());

    registerPropertyWidgetFactory(new CorePropertyWidgetFactory());
}

} // namespace
